@@ -5,7 +5,7 @@ from djangoldp_circle.models import Circle
 
        
 class Typeevent (Model):
-    name = models.CharField(max_length=20, verbose_name="Type d'évènement")
+    name = models.CharField(max_length=50, verbose_name="Type d'évènement")
 
     class Meta : 
         anonymous_perms = ['view', 'add']
@@ -31,7 +31,7 @@ class Event (Model):
     startTime = models.TimeField(verbose_name="Heure de début")
     endDate =  models.DateField(verbose_name="Date de fin",blank=True, null=True )
     endTime =  models.TimeField(verbose_name="Heure de fin",blank=True, null=True )
-    img = models.URLField(blank=True, null=True, verbose_name="Illustration de l'évènement")
+    img = models.URLField(default="/media/defaultevent.png", verbose_name="Illustration de l'évènement")
     location = models.ForeignKey(Locationevent, blank=True, null=True, verbose_name="Lieu de l'évènement")
     shortDescription = models.CharField(max_length=250,verbose_name="Short description")
     longDescription = models.TextField(verbose_name="Long description")
